@@ -714,7 +714,8 @@ def importModule(resourceModuleName, muteLogs=False, reload=False, ignoreList=IG
                     return IMPORT_CASHE.get(resourceModuleName)
                 except Exception as exception:
                     importException = exception
-            raise Exception(f'Not possible to import module "{resourceModuleName}"{c.DOT_SPACE_CAUSE}{getExceptionTextWithoutDotAtTheEnd(importException)}{DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION}')
+                    dotSpaceCause = f'{c.DOT_SPACE_CAUSE}{getExceptionTextWithoutDotAtTheEnd(importException)}'
+            raise Exception(f'Not possible to import module "{resourceModuleName}"{dotSpaceCause}{c.BLANK if dotSpaceCause.endswith(DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION) else DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION}')
         return IMPORT_CASHE.get(resourceModuleName)
 
 
@@ -754,8 +755,8 @@ def importResource(resourceName, resourceModuleName=None, muteLogs=False, reload
             if not muteLogs :
                 log.log(importResource, f'Not possible to import "{resourceName}" resource from "{resourceModuleName}" module', exception=exception)
         if required and ObjectHelper.isNone(accumulatedResourceModule):
-            cause = getExceptionTextWithoutDotAtTheEnd(importException)
-            raise Exception(f'Error while importing {innerResourceName} resource from {resourceModuleName} module{c.DOT_SPACE_CAUSE}{cause}{c.BLANK if f"{c.DOT_SPACE_CAUSE}{cause}".endswith(DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION) else DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION}')
+            dotSpaceCause = f'{c.DOT_SPACE_CAUSE}{getExceptionTextWithoutDotAtTheEnd(importException)}'
+            raise Exception(f'Error while importing {innerResourceName} resource from {resourceModuleName} module{dotSpaceCause}{c.BLANK if dotSpaceCause.endswith(DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION) else DOT_SPACE_CHECK_LOG_LEVEL_LOGS_FOR_MORE_INFORMATION}')
         return IMPORT_CASHE.get(getCompositeModuleName(resourceModuleName, nameList))
 
 
